# PySBOLGraph

PySBOLGraph is a simple native Python library to read and write [SBOL2](http://sbolstandard.org) files, compatible with both Python 2.7 and Python 3.

Install using ``pip install pysbolgraph``, or clone this repository and run ``python setup.py install``

## Examples

The file ``crispr.py`` reproduces the CRISPR example that is also used in the tutorials for [libSBOL](http://sbolstandard.org/wp-content/uploads/2017/01/libSBOL-tutorial.pdf), [libSBOLj](http://sbolstandard.org/wp-content/uploads/2015/01/libSBOLjTutorial.pdf), [sboljs](http://sbolstandard.org/wp-content/uploads/2015/01/sboljs_tutorial.pdf) and [pysbol](http://sbolstandard.org/wp-content/uploads/2018/05/pysbol-crispr-tutorial_v2.pdf). 

## See also

For a more powerful library with features such as automated sequence assembly, check out [pysbol](https://github.com/SynBioDex/pySBOL).

For a JavaScript/TypeScript version of this library, check out [the original sbolgraph](https://github.com/udp/sbolgraph).
